@@ -8,12 +8,17 @@
 #ifndef MASTERCONTROL_H_
 #define MASTERCONTROL_H_
 
-#include <QString>
+#include "config.h"
 
-// std::shared_ptr
+#if defined(HAVE_STD_SHARED_PTR)
 #include <memory>
+using std::shared_ptr;
+#elif defined(HAVE_STD_TR1_SHARED_PTR)
 #include <tr1/memory>
-using namespace ::std::tr1;
+using std::tr1::shared_ptr;
+#endif
+
+#include <QString>
 
 class MasterControl
 {
